Stan Math Library: stan/math/fwd/core/operator_greater_than_or_equal.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
operator_greater_than_or_equal.hpp File Reference
`#include <stan/math/fwd/core/fvar.hpp>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T >
bool | stan::math::operator>= (const fvar< T > &x, const fvar< T > &y)
template<typename T >
bool | stan::math::operator>= (const fvar< T > &x, double y)
template<typename T >
bool | stan::math::operator>= (double x, const fvar< T > &y)

[ Stan Home Page ] © 2011–2016, Stan Development Team.